import { Component, OnChanges, SimpleChanges, Input } from '@angular/core';
import { DataLogsService } from 'src/app/services/data-logs.service';
import { PaginatorOptions } from 'src/app/models/paginator-options.model';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { switchMap } from 'rxjs/operators';
import { ILogs } from 'src/app/models/logs.model';
import { FormsModule } from '@angular/forms';
import { Subscription } from 'rxjs';

@Component({
  selector: 'app-logs-sessions',
  templateUrl: './logs-sessions.component.html',
  styleUrls: ['./logs-sessions.component.scss'],
})
export class LogsSessionsComponent implements OnChanges {
  // @Input() childSessionId: string;
  // @Input() childSessionsList: [];
  @Input() childNbSessions: number;
  sessionChangeSub: Subscription;
  nbSessions: number = 0;
  allSessionsIdInfo: any = [];
  allSessionsInfoList: any = [];
  paginator: PaginatorOptions;
  urlCode: string = 'sessionUrl';
  constructor(
    private dataLogsService: DataLogsService,
  ) {
    this.paginator = {
      pageIndex: this.dataLogsService.pageNumber,
      length: 1,
      limit: this.dataLogsService.limit,
      pageSizeOptions: [5, 10, 20],
    };
  }

  ngOnChanges(changes: SimpleChanges): void {
    this.sessionChangeSub = this.dataLogsService.sessionLogChange$.subscribe(
      () => {
        this.paginator.limit = this.dataLogsService.limit;
        this.paginator.pageIndex = this.dataLogsService.pageNumber;
        this.paginator.length = this.dataLogsService.length;
        this.getAllSessionsInfo(this.childNbSessions, this.paginator.pageIndex);
      },
    );
    this.getAllSessionsInfo(this.childNbSessions, 1);
  }
  ngOnDestroy() {
    this.sessionChangeSub.unsubscribe();
  }

  getProcessTimeAggr (sessionId) {
    this.dataLogsService.getProcessTimeAggr(sessionId).subscribe((result) => {
      // console.log(result[0]);
      this.allSessionsIdInfo.push(result[0]);
    },
    );
  }

  getAllSessionsInfo(length, pageNumber) {
    this.dataLogsService.getAllInfoForAllSessions(length, pageNumber).subscribe((result) => {
      this.allSessionsInfoList = result;
      this.nbSessions = result.length;
      this.paginator.limit = this.dataLogsService.limit;
      this.paginator.pageIndex = this.dataLogsService.pageNumber;
      this.paginator.length = this.childNbSessions;
      console.log('allSessionsInfoList: ', this.allSessionsInfoList);
      this.formatDate();
    },
    );

  }
  formatDate() {
    for (let i = 0; i < this.nbSessions; i += 1) {
      for (let j = 0; j < this.allSessionsInfoList[i].data.length; j += 1) {
        // const date1 = new Date(this.allSlugsInfoList[i].data[j].completionDate.$date);
        // const date2 = new Date(this.allSlugsInfoList[i].data[j].startDate.$date);
        // this.allSlugsInfoList[i].data[j].duration =
        // Math.round((this.allSlugsInfoList[i].data[j].completionDate.$date - this.allSlugsInfoList[i].data[j].startDate.$date) / 60000);
        this.allSessionsInfoList[i].data[j].completionDate.$date = new Date(this.allSessionsInfoList[i].data[j].completionDate.$date);
      }
    }
  }

    // When pagination is changed by user, we update datasetList with new pagination options
  changePagination(pageIndex) {
    this.dataLogsService.paginationChanged(this.paginator.limit, pageIndex, 'SESSION');
  }

  changePageSize(pageSize) {
    this.dataLogsService.paginationChanged(pageSize, 1, 'SESSION');
  }
}
