import { Component, OnChanges, SimpleChanges, Input } from '@angular/core';
import { DataLogsService } from 'src/app/services/data-logs.service';
import { PaginatorOptions } from 'src/app/models/paginator-options.model';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { switchMap } from 'rxjs/operators';
import { ILogs } from 'src/app/models/logs.model';
import { FormsModule } from '@angular/forms';
import { Subscription } from 'rxjs';

@Component({
  selector: 'app-logs-slugs',
  templateUrl: './logs-slugs.component.html',
  styleUrls: ['./logs-slugs.component.scss'],
})
export class LogsSlugsComponent implements OnChanges {
  @Input() childNbSlugs: number;
  urlCode: string = 'slugUrl';
  slugChangeSub: Subscription;
  allSlugsInfoList:any = [];
  slugInOnePage:number = 1;
  allSessionsIdInfo:any = [];
  childSessionsList: any;
  paginator: PaginatorOptions;
  constructor(
    private dataLogsService: DataLogsService,
  ) {
    this.paginator = {
      pageIndex: this.dataLogsService.pageNumber,
      length: 1,
      limit: this.dataLogsService.limit,
      pageSizeOptions: [5, 10, 20],
    };
  }

  ngOnChanges(changes: SimpleChanges): void {
    this.allSlugsInfoList = [];
    this.slugChangeSub = this.dataLogsService.slugLogChange$.subscribe(
      () => {
        this.paginator.limit = this.dataLogsService.limit;
        this.paginator.pageIndex = this.dataLogsService.pageNumber;
        this.paginator.length = this.childNbSlugs;
        this.getAllInfoForAllSlugs(this.childNbSlugs, this.paginator.pageIndex);
      },
    );
    this.getAllInfoForAllSlugs(this.childNbSlugs, 1);
  }
  ngOnDestroy() {
    this.slugChangeSub.unsubscribe();
  }
  getAllInfoForAllSlugs(length, pageNumber) {
    this.dataLogsService.getAllInfoForAllSlugs(length, pageNumber).subscribe((result) => {
      this.allSlugsInfoList = result;
      this.slugInOnePage = result.length;
      this.paginator.limit = this.dataLogsService.limit;
      this.paginator.pageIndex = this.dataLogsService.pageNumber;
      this.paginator.length = this.childNbSlugs;
      console.log('allSlugsInfoList: ', this.allSlugsInfoList);
      this.formatDate();
    },
    );

  }
  formatDate() {
    for (let i = 0; i < this.slugInOnePage; i += 1) {
      for (let j = 0; j < this.allSlugsInfoList[i].data.length; j += 1) {
        // const date1 = new Date(this.allSlugsInfoList[i].data[j].completionDate.$date);
        // const date2 = new Date(this.allSlugsInfoList[i].data[j].startDate.$date);
        // this.allSlugsInfoList[i].data[j].duration =
        // Math.round((this.allSlugsInfoList[i].data[j].completionDate.$date - this.allSlugsInfoList[i].data[j].startDate.$date) / 60000);
        this.allSlugsInfoList[i].data[j].completionDate.$date = new Date(this.allSlugsInfoList[i].data[j].completionDate.$date);
      }
    }
  }
    // When pagination is changed by user, we update datasetList with new pagination options
  changePagination(pageIndex) {
    this.dataLogsService.paginationChanged(this.paginator.limit, pageIndex, 'SLUG');
  }

  changePageSize(pageSize) {
    this.dataLogsService.paginationChanged(pageSize, 1, 'SLUG');
  }
}
