import { Component, OnChanges, SimpleChanges, Input } from '@angular/core';
import { DataLogsService } from 'src/app/services/data-logs.service';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { switchMap } from 'rxjs/operators';
import { ILogs } from 'src/app/models/logs.model';
import { FormsModule } from '@angular/forms';
import { PaginatorOptions } from 'src/app/models/paginator-options.model';
import { Subscription } from 'rxjs';

@Component({
  selector: 'app-logs-error',
  templateUrl: './logs-error.component.html',
  styleUrls: ['./logs-error.component.scss'],
})
export class LogsErrorComponent implements OnChanges {
  @Input() childUuid: string = '';
  @Input() childSessionId: string = '';
  @Input() childSlug: string;
  errorLogChangeSub: Subscription;
  selectedStep  = {
    step:'main',
    nbErrors: 0,
    nbInfos: 0,
  };

  displayedStep: string = 'none';
  logTypes: any = [
    {
      name : 'erreurs',
      selected : true,
    },
    {
      name : 'infos',
      selected : false,
    },
  ];
  uuid: string;
  sessionId: string;
  slug: string;
  data: any;
  stepData: ILogs;
  allStepsData: any;
  allErrorLogs: any;
  allLogs: any;
  nbSessionId: number;
  nbUuid: number;
  nbSlug: number;
  // Paginator options
  paginator: PaginatorOptions;
  pageSizeOptions = [5, 10, 25, 100];
  sessionIdList: [string];
  constructor(
    private dataLogsService: DataLogsService,
    private route: ActivatedRoute,
  ) {
    this.paginator = {
      pageIndex: this.dataLogsService.pageNumber,
      length: 1,
      limit: this.dataLogsService.limit,
      pageSizeOptions: [5, 10, 20],
    };
  }

  ngOnChanges(changes: SimpleChanges): void {
    this.data = [];
    this.slug = this.childSlug;
    this.allStepsData = [];
    this.allErrorLogs = [];
    this.getLogsSteps();
    this.errorLogChangeSub = this.dataLogsService.errorLogChange$.subscribe(
      () => {
        this.paginator.limit = this.dataLogsService.limit;
        this.paginator.pageIndex = this.dataLogsService.pageNumber;
        if (this.logTypes[0].selected === true) {
          this.getErrorStepsLogs(this.selectedStep.step, this.selectedStep.nbErrors, this.paginator.pageIndex);
        }
        if (this.logTypes[1].selected === true) {
          this.getSimpleStepsLogs(this.selectedStep.step, this.selectedStep.nbInfos, this.paginator.pageIndex);
        }
      },
    );
  }
  ngOnDestroy() {
    this.errorLogChangeSub.unsubscribe();
  }
  getLogsSteps() {
    if ((this.childUuid != null) && (this.childSessionId != null)) {
      // console.log('parameters', this.childUuid, this.childSessionId);

      this.dataLogsService.getAllStepsDuration(
        this.childUuid,
        this.childSessionId,
      ).subscribe((results) => {
        console.log('getAllStepsDuration results', results);
        this.allStepsData = results;
      },
      );
    }
  }
  getLogsSelector(step, counts) {
    this.selectedStep.step = step;
    this.selectedStep.nbErrors = counts.ERROR;
    this.selectedStep.nbInfos = counts.INFO;
    this.allErrorLogs = [];
    this.allLogs = [];
    this.displayedStep = step;
    if (this.logTypes[0].selected === true) {
      this.getErrorStepsLogs(step, this.selectedStep.nbErrors, 1);
    }
    if (this.logTypes[1].selected === true) {
      this.getSimpleStepsLogs(step, this.selectedStep.nbInfos, 1);
    }
  }
  getErrorStepsLogs(step, nbErrors, pageNumber) {
    if ((this.childUuid != null) && (this.childSessionId != null)) {
      // console.log('parameters', this.childUuid, this.childSessionId);

      this.dataLogsService.getLogsStepsLogs(
        step,
        this.childSessionId,
        this.childUuid,
        'ERROR',
        nbErrors,
        pageNumber,
      ).subscribe((results) => {
        // console.log('results', results);
        this.allErrorLogs = results;
        this.paginator.limit = this.dataLogsService.limit;
        this.paginator.pageIndex = this.dataLogsService.pageNumber;
        this.paginator.length = this.dataLogsService.length;
      },
      );
    }
  }
  getSimpleStepsLogs(step, nbInfos, pageNumber) {
    if ((this.childUuid != null) && (this.childSessionId != null)) {
      // console.log('parameters', this.childUuid, this.childSessionId);

      this.dataLogsService.getLogsStepsLogs(
        step,
        this.childSessionId,
        this.childUuid,
        'INFO',
        nbInfos,
        pageNumber,
      ).subscribe((results) => {
        // console.log('results', results);
        this.allLogs = results;
        this.paginator.limit = this.dataLogsService.limit;
        this.paginator.pageIndex = this.dataLogsService.pageNumber;
        this.paginator.length = this.dataLogsService.length;
      },
      );
    }
  }

    // When pagination is changed by user, we update datasetList with new pagination options
  changePagination(pageIndex) {
    this.dataLogsService.paginationChanged(this.paginator.limit, pageIndex, 'ERROR');
  }

  changePageSize(pageSize) {
    this.dataLogsService.paginationChanged(pageSize, 1, 'ERROR');
  }
}
