import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { filter, switchMap } from 'rxjs/operators';
import { Format } from 'src/app/models/format.model';
import { DataLogsService } from 'src/app/services/data-logs.service';
import { IPageHeaderInfo } from 'src/app/models/page.model';
import { ISimpleTab } from 'src/app/models/basic-tabs.model';

@Component({
  selector: 'app-logs-report',
  templateUrl: './logs-report.component.html',
  styleUrls: ['./logs-report.component.scss'],
})
export class LogsReportComponent implements OnInit {
  pageHeaderInfo: IPageHeaderInfo = {
    title: 'Data-Logs Report',
  };
  responseArray: any = [];
  isToggled: boolean = true;
  form: FormGroup;
  title: string;
  slug: string ;
  uuid:string;
  sessionId: string;
  serviceName:string;
  nbObjects: number = 0;
  urlCode: string = '';
  isSession:boolean = false;
  previousUrl: string;
  tabs: ISimpleTab[] =  [
    {
      name: 'Graph',
      isActive: true,
    },
    {
      name: 'Infos',
      isActive: false,
    },
    {
      name: 'Errors',
      isActive: false,
    },
  ];
  constructor(
    private _dataLogsService: DataLogsService,
    private _route: ActivatedRoute,
    private _router: Router,
    private _fb: FormBuilder,
  ) {
  }

  ngOnInit() {
    this.title = this._route.snapshot.data.title;
    this.sessionId = this._route.snapshot.paramMap.get('sessionId');
    this.slug = this._route.snapshot.paramMap.get('slug');
    this.urlCode = this._route.snapshot.paramMap.get('urlCode');
    if (this.urlCode === 'session') {
      this.previousUrl = `/datalogs/preReport/session/${this.sessionId}`;

    } else if (this.urlCode === 'slug') {
      this.previousUrl = `/datalogs/preReport/slug/${this.slug}`;
    } else {
      this.previousUrl = '/datalogs';
    }
    this.getUuidFromSlug(this.slug);
  }

  getUuidFromSlug(slug) {
    this._dataLogsService.getUuidFromSlug(slug).subscribe((result) => {
      // console.log(result[0]);
      this.uuid = result[0].uuid_list[0];
    },
    );
  }

  tabsToggler(tabName) {
    if (tabName === 'Graph') {
      this.isToggled = true;
      this.tabs[1].isActive = false;
      this.tabs[0].isActive = true;
      this.tabs[2].isActive = false;

    }
    if (tabName === 'Infos') {
      this.isToggled = false;
      this.tabs[1].isActive = true;
      this.tabs[0].isActive = false;
      this.tabs[2].isActive = false;

    }
    if (tabName === 'Errors') {
      this.isToggled = undefined;
      this.tabs[2].isActive = true;
      this.tabs[1].isActive = false;
      this.tabs[0].isActive = false;
    }
  }

}
