import { Injectable } from '@angular/core';
import { Observable, Subject, from } from 'rxjs';
import { map, concatMap } from 'rxjs/operators';
import { HttpClient } from '@angular/common/http';
import { Resource, IResource, ResourceRO, IResourceFormat } from '../models/resource.model';
import { APP_CONFIG } from './app-config.service';

@Injectable()
export class DataLogsService {

  resourceServiceUrl: string;
  limit: number;
  pageNumber: number;
  length: number;
  sortOptions: {
    value: string,
    order: string,
  };

  private _infoLogSubject: Subject<any>;
  private _errorLogSubject: Subject<any>;
  private _sessionLogSubject: Subject<any>;
  private _slugLogSubject: Subject<any>;

  constructor(
    private _httpClient: HttpClient) {
    this.resourceServiceUrl = `${APP_CONFIG.restHeartAggregations.url}`;
    this._infoLogSubject = new Subject<any>();
    this._errorLogSubject = new Subject<any>();
    this._sessionLogSubject = new Subject<any>();
    this._slugLogSubject = new Subject<any>();

    this.limit = 6;
    this.pageNumber = 1;
    this.length = 1;
  }

  uuidToSessionId(uuid): Observable<any[]> {
    const query = { uuid };
    const aggregationEndPoint = '/_aggrs/uuidToSessionId?avars=';
    const stringQuery = JSON.stringify(query);
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getAllStepsDuration(uuid, sessionId): Observable<any[]> {
    const query = { uuid, session_id: sessionId };
    const aggregationEndPoint = '/_aggrs/stepTimeAggr?avars=';
    const stringQuery = JSON.stringify(query);
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }
  getAllUniqueFields(): Observable<any[]> {
    const aggregationEndPoint = '/_aggrs/getAllUniqueFields';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint).pipe(
      map((response) => {
        return response;
      }),
    );
  }
  getAllInfoForAllSlugs(nbSlugs, pageNumber): Observable<any[]> {
    let aggregationEndPoint = '/_aggrs/allFullSlugAggr';
    this.length = nbSlugs;
    this.pageNumber = pageNumber;
    aggregationEndPoint += `?pagesize=${(this.limit)}`;
    aggregationEndPoint += `&page=${(pageNumber)}`;
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getAllInfoForAllSessions(nbSessions, pageNumber): Observable<any[]> {
    let aggregationEndPoint = '/_aggrs/allFullSessionAggr';
    this.length = nbSessions;
    this.pageNumber = pageNumber;
    aggregationEndPoint += `?pagesize=${(this.limit)}`;
    aggregationEndPoint += `&page=${(pageNumber)}`;
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint).pipe(
      map((response) => {
        return response;
      }),
    );
  }
  getAllInfoForOneSlug(slug): Observable<any[]> {
    const query = { slug };
    const stringQuery = JSON.stringify(query);
    const aggregationEndPoint = '/_aggrs/oneFullSlugAggr?avars=';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getAllInfoForOneSession(sessionId): Observable<any[]> {
    const query = { session_id: sessionId };
    const stringQuery = JSON.stringify(query);
    const aggregationEndPoint = '/_aggrs/oneFullSessionAggr?avars=';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getData(thisUuid, sessionId): Observable<any[]> {
    const query = { uuid: thisUuid, session_id: sessionId };
    const stringQuery = JSON.stringify(query);
    const aggregationEndPoint = '/_aggrs/reportDataAggr?avars=';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }
  getProcessTimeAggr(sessionId): Observable<any[]> {
    const query = { session_id: sessionId };
    const stringQuery = JSON.stringify(query);
    const aggregationEndPoint = '/_aggrs/processTimeAggr?avars=';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getSlugFromSessionId(sessionId): Observable<any[]> {
    const query = { session_id: sessionId };
    const stringQuery = JSON.stringify(query);
    const aggregationEndPoint = '/_aggrs/sessionIdToSlug?avars=';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getUuidFromSlug(slug): Observable<any[]> {
    const query = { slug };
    const stringQuery = JSON.stringify(query);
    const aggregationEndPoint = '/_aggrs/slugToUuid?avars=';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getSessionIdFromSlug(slug): Observable<any[]> {
    const query = { slug };
    const stringQuery = JSON.stringify(query);
    const aggregationEndPoint = '/_aggrs/slugToSessionId?avars=';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getLogsFromSessionIdAndSlug(sessionId, slug, loglevel): Observable<any[]> {
    const query = { slug, loglevel, session_id : sessionId };
    const stringQuery = JSON.stringify(query);
    const aggregationEndPoint = '?filter=';
    return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getLogsStepsLogs(step, sessionId, uuid, loglevel, nbLogs, pageNumber): Observable<any[]> {
    const query = { step, uuid, loglevel, session_id : sessionId };
    let stringQuery = JSON.stringify(query);
    this.length = nbLogs;
    this.pageNumber = pageNumber;
    stringQuery += `&pagesize=${(this.limit)}`;
    stringQuery += `&page=${(pageNumber)}`;
    const aggregationEndPoint = '?filter=';
    return this._httpClient.get<any>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
      map((response) => {
        return response;
      }),
    );
  }

  getComplementaryFromSlugOrSession(type, typeInfo): Observable<any[]> {
    if (type === 'slug') {
      const query = { slug: typeInfo };
      const stringQuery = JSON.stringify(query);
      const aggregationEndPoint = '/_aggrs/slugToSessionId?avars=';
      return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
        map((response) => {
          return response;
        }),
      );

    } else {
      const query = { session_id: typeInfo };
      const stringQuery = JSON.stringify(query);
      const aggregationEndPoint = '/_aggrs/sessionIdToSlug?avars=';
      return this._httpClient.get<any[]>(this.resourceServiceUrl + aggregationEndPoint + stringQuery).pipe(
        map((response) => {
          return response;
        }),
      );
    }

  }

    /* PAGINATION */
  paginationChanged(limit: number, pageNumber: number, logType:string) {
    this.limit = limit;
    this.pageNumber = pageNumber;
    console.log('paginationChanged', 'limit: ',    this.limit, 'pageNumber: ', this.pageNumber, 'length', this.length);
    if (logType === 'INFO') {
      this._infoLogSubject.next();
    }if (logType === 'ERROR') {
      this._errorLogSubject.next();
    }if (logType === 'SLUG') {
      this._slugLogSubject.next();
    }if (logType === 'SESSION') {
      this._sessionLogSubject.next();
    }
  }

  reverseSortOrder(): void {
    if (this.sortOptions.order === 'asc') {
      this.sortOptions.order = 'desc';
    } else {
      this.sortOptions.order = 'asc';
    }
  }
  get infoLogChange$(): Observable<string> {
    return this._infoLogSubject.asObservable();
  }
  get errorLogChange$(): Observable<string> {
    return this._errorLogSubject.asObservable();
  }
  get sessionLogChange$(): Observable<string> {
    return this._sessionLogSubject.asObservable();
  }
  get slugLogChange$(): Observable<string> {
    return this._slugLogSubject.asObservable();
  }

}
